{% extends "textbin/base.html" %}

{% block title %}404 |{% endblock %}

{% block body %}
<div class="container">
    <p class="text-danger">{{ status }}Ошибка 404: не найдено ни одной записи, соответствующей запросу :(</p>
</div>
{% endblock %}