<div class="navbar navbar-default">
    <div class="container">
        <span class="navbar-brand">Textbin
            <span style="font-size: 60%">&mdash; the place to share your posts</span>
        </span>
    </div>
</div>