{% load staticfiles %}

{% load bootstrap3 %}

<!DOCTYPE html>
<html lang="ru">
<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">

    {% block extrahead %}{% endblock %}

    <title>{% block title %}{% endblock %} Textbin</title>
</head>
<body>
    <header>
        {% include 'textbin/includes/header.html' %}
    </header>

    <section id="content_body">
        {% block body %}{% endblock %}
    </section>

    <footer>
        {% include 'textbin/includes/footer.html' %}
    </footer>

    {% block js %}{% endblock %}
</body>
</html>